==> malt-0.0.3.tgz: package/lib/core/index.js <==
var beanpole = require('beanpole/lib/core'),
hookBean = require('beanpole/lib/core/beans/hook.core'),
// hookHttpBean = require('beanpole/node/beans/hook.http.mesh.mesh'),
socketBean = require('beanpole/lib/web/beans/hook.socket.io.client'),
models = require('./core/models'),
Schema = require('./core/schema'),
modifiers = require('./core/modifiers');

models.Item = require('./core/models/item');
models.Collection = require('./core/models/collection');
models.Model = require('./core/models/concrete').Model;


exports.models = models;
exports.modifiers = modifiers;



exports._initModel = function(Model, name, appModels, router)
{
	var AppModel = Model.extend({ router: router, 


		models: appModels, 

		//used for serialization
		name: Model.prototype.name || name,

		//schema for the model
		_schema: new Schema(Model.schema, modifiers)
	});


	appModels[name] = appModels[AppModel.prototype.name] = appModels[Model.prototype.channel] = AppModel;
}

exports._init = function(router)
{
	var hostModels = {};

	for(var name in models)
	{
		var Model = models[name];

		if(!Model.extend) continue;

		exports._initModel(Model, name, hostModels , router);
	}

	return hostModels;
} 


exports.connect = function(host, onConnect)
{
	var router = beanpole.router();


	router.models = exports._init(router);


	//hook core 
	hookBean.plugin(router);

	//hook via websockets
	socketBean.plugin(router);

	if(onConnect) router.on('push -one -public spice.io/ready', function()
	{
		onConnect(router);
	})

	router.push('init');

	return router;
}

==> malt-0.0.7.tgz: package/lib/core/index.js <==
var beanpole = require('beanpole/lib/core'),
hookBean = require('beanpole/lib/core/beans/hook.core'),
// hookHttpBean = require('beanpole/node/beans/hook.http.mesh.mesh'),
socketBean = require('beanpole/lib/web/beans/hook.socket.io.client'),
models = require('./core/models'),
Schema = require('./core/schema'),
modifiers = require('./core/modifiers');

models.Item = require('./core/models/item');
models.Collection = require('./core/models/collection');
models.Model = require('./core/models/concrete').Model;


exports.models = models;
exports.modifiers = modifiers;



exports._initModel = function(Model, name, appModels, router)
{
	var AppModel = Model.extend({ router: router, 


		models: appModels, 

		//used for serialization
		name: Model.prototype.name || name,

		//schema for the model
		_schema: new Schema(Model.schema, modifiers)
	});


	appModels[name] = appModels[AppModel.prototype.name] = appModels[Model.prototype.channel] = AppModel;
}

exports._init = function(router)
{
	var hostModels = {};

	for(var name in models)
	{
		var Model = models[name];

		if(!Model.extend) continue;

		exports._initModel(Model, name, hostModels , router);
	}

	return hostModels;
} 


exports.connect = function(host, onConnect)
{
	var router = beanpole.router();


	router.models = exports._init(router);


	//hook core 
	hookBean.plugin(router);

	//hook via websockets
	socketBean.plugin(router);

   	if(onConnect) router.on('push -one -public '+appName+'/ready', function()
	{
		onConnect(router);
	})

	router.push('init');

	return router;
}
